![Build](https://github.com/cchdo/hydro/workflows/Build/badge.svg)
[![Coverage Status](https://coveralls.io/repos/github/cchdo/hydro/badge.svg)](https://coveralls.io/github/cchdo/hydro)
[![Documentation Status](https://readthedocs.org/projects/hydro/badge/?version=latest)](https://hydro.readthedocs.io/en/latest/?badge=latest)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)
[![SPEC 0 — Minimum Supported Dependencies](https://img.shields.io/badge/SPEC-0-green?labelColor=%23004811&color=%235CA038)](https://scientific-python.org/specs/spec-0000/)
[![DOI](https://zenodo.org/badge/149519611.svg)](https://zenodo.org/doi/10.5281/zenodo.10858970)


hydro
=====
The new libcchdo based on xarray/pandas.
